@@ -14,26 +14,34 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 	}
 	
 	model_cur <- AtCtEt
+	
+	l_a <- model_cur$n_beta_a
+	l_c <- model_cur$n_beta_c
+	l_e <- model_cur$n_beta_e
 
 	#pheno_m <- c(t(data_m[,1:2]))
 	#pheno_d <- c(t(data_d[,1:2]))
 	#T_m <- rep(data_m[,3], each=2)
 	#T_d <- rep(data_d[,3], each=2)
-
+  n_beta <- 1:(l_a+l_c+l_e)
 	order <- 3
 	x <- seq(from=model_cur$min_t, to=model_cur$max_t, length.out=500)
-	if(model_cur$n_beta_c>1)
-	{
-		bb_c <- splineDesign(model_cur$knots_c, x = x, ord=order, outer.ok = TRUE)
-	}else{
-		bb_c <- splineDesign(model_cur$knots_c, x = x, ord=1, outer.ok = TRUE)
-	}
-	
 	if(model_cur$n_beta_a>1)
 	{
 		bb_a <- splineDesign(model_cur$knots_a, x = x, ord=order, outer.ok = TRUE)
 	}else{
 		bb_a <- splineDesign(model_cur$knots_a, x = x, ord=1, outer.ok = TRUE)
+		if(model_cur$beta_a[1]==-Inf)
+		{n_beta[1]=0}
+	}
+	
+	if(model_cur$n_beta_c>1)
+	{
+		bb_c <- splineDesign(model_cur$knots_c, x = x, ord=order, outer.ok = TRUE)
+	}else{
+		bb_c <- splineDesign(model_cur$knots_c, x = x, ord=1, outer.ok = TRUE)
+		if(model_cur$beta_c[1]==-Inf)
+		{n_beta[model_cur$n_beta_a+1]=0}
 	}
 	
 	if(model_cur$n_beta_e>1)
@@ -43,15 +51,12 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 		bb_e <- splineDesign(model_cur$knots_e, x = x, ord=1, outer.ok = TRUE)
 	}
 
-	l_a <- model_cur$n_beta_a
-	l_c <- model_cur$n_beta_c
-	l_e <- model_cur$n_beta_e
 	points_a <- exp(bb_a%*%model_cur$beta_a)
 	points_c <- exp(bb_c%*%model_cur$beta_c)
 	points_e <- exp(bb_e%*%model_cur$beta_e)
 
 	#fisher <- solve(model_cur$hessian[2:(1+l_a+l_c),2:(1+l_a+l_c)])
-	fisher <- solve(model_cur$hessian)
+	fisher <- solve(model_cur$hessian[n_beta,n_beta])
 	
 	max_v <- max(points_c, points_a, points_e)*1.2
 	plot(range(x), c(0,max_v), type = "n", xlab = "Age", ylab = "Variance",main =  "Variance curves of the A, C, and E components")
@@ -76,7 +81,7 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 	
 	}else{
 	
-	if((l_a>1)|(model_cur$beta_a[1]!=0))
+	if((l_a>1)|(model_cur$beta_a[1]!=-Inf))
 	{
 	
 	fisher_a <- fisher[index:l_a,index:l_a]
@@ -102,6 +107,7 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 	#}
 	lower <- ifelse(lower<0, 0, lower)
 	upper <- ifelse(upper>max_v, max_v, upper)
+	index <- index + l_a
 	if(flag == 0)
 	{
 	lines(x, lower, col = "orange" ,lty = 2 , lwd = 0.6)
@@ -109,11 +115,9 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 	polygon(c(x, rev(x)),c(upper, rev(lower)),col='grey',border = NA, lty=3, density=20)
 	}else{warning('The variance of one of the estimates from the Delta method for the A component is negative. Please try the bootstrap method for the confidence interval or use a different model.')}
 	}
-
-	index <- index + l_a
 	
 	
-	if((l_c>1)|(model_cur$beta_c[1]!=0))
+	if((l_c>1)|(model_cur$beta_c[1]!=-Inf))
 	{
 	fisher_c <- fisher[index:(index+l_c-1),index:(index+l_c-1)]
 	
@@ -138,6 +142,7 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 	#}
 	lower <- ifelse(lower<0, 0, lower)
 	upper <- ifelse(upper>max_v, max_v, upper)
+	index <- index + l_c
 	if(flag == 0)
 	{
 	lines(x, lower, col = "green" ,lty = 2 , lwd = 0.6)
@@ -146,8 +151,6 @@ plot_AtCtEt <- function(AtCtEt, boot=FALSE)
 	}else{warning('The variance of one of the estimates from the Delta method for the C component is negative. Please try the bootstrap method for the confidence interval or use a different model.')}
 
 	}
-
-	index <- index + l_c
 	
 	fisher_e <- fisher[index:(index+l_e-1),index:(index+l_e-1)]
 	lower <- rep(NA, length(x))
