@@ -18,12 +18,16 @@ plot_AtCtEtp <- function(AtCtEtp_mcmc)
 	t_int <- model_cur$max_t-model_cur$min_t
 	l_m_1 <- (model_cur$max_t-x)/t_int
 	l_m_2 <- (x-model_cur$min_t)/t_int
+	
+	n_a <- length(model_cur$beta_a_mc)
+	n_c <- length(model_cur$beta_c_mc)
+	n_e <- length(model_cur$beta_e_mc)
 
-	if(length(model_cur$beta_a_mc)>2)
+	if(n_a>2)
 	{
 		bb_a <- splineDesign(model_cur$knots_a, x = x, ord=order, outer.ok = TRUE)
 	}else{
-		if(length(model_cur$beta_a_mc)==2)
+		if(n_a==2)
 		{
 			bb_a <- matrix(NA, p_n, 2)
 			bb_a[,1] <- l_m_1
@@ -34,11 +38,11 @@ plot_AtCtEtp <- function(AtCtEtp_mcmc)
 	}
 	points_a <- exp(bb_a%*%model_cur$beta_a_mc)
 
-	if(length(model_cur$beta_c_mc)>2)
+	if(n_c>2)
 	{
 		bb_c <- splineDesign(model_cur$knots_c, x = x, ord=order, outer.ok = TRUE)
 	}else{
-		if(length(model_cur$beta_c_mc)==2)
+		if(n_c==2)
 		{
 			bb_c <- matrix(NA, p_n, 2)
 			bb_c[,1] <- l_m_1
@@ -49,11 +53,11 @@ plot_AtCtEtp <- function(AtCtEtp_mcmc)
 	}
 	points_c <- exp(bb_c%*%model_cur$beta_c_mc)
 
-	if(length(model_cur$beta_e_mc)>2)
+	if(n_e>2)
 	{
 		bb_e <- splineDesign(model_cur$knots_e, x = x, ord=order, outer.ok = TRUE)
 	}else{
-		if(length(model_cur$beta_e_mc)==2)
+		if(n_e==2)
 		{
 			bb_e <- matrix(NA, p_n, 2)
 			bb_e[,1] <- l_m_1
@@ -65,28 +69,11 @@ plot_AtCtEtp <- function(AtCtEtp_mcmc)
 	points_e <- exp(bb_e%*%model_cur$beta_e_mc)
 
 	plot(range(x), c(0,max(points_c, points_a, points_e)+1), type = "n", xlab = "Age", ylab = "Variance",main =  "Variance curves of the A, C and E components")
-	lines(x, points_c, col = "blue", lwd = 2)
-	fisher_c <- model_cur$cov_c_mc
-	lower <- rep(NA, length(x))
-	upper <- rep(NA, length(x))
-	sd <- rep(NA, length(x))
-
-	for(i in 1:length(x))
-	{
-		sd[i] <- sqrt((t(bb_c[i,])%*%fisher_c%*%bb_c[i,]))
-		lower[i] <- sum(bb_c[i,]*model_cur$beta_c_mc) - 1.96*sd[i]
-		upper[i] <- sum(bb_c[i,]*model_cur$beta_c_mc) + 1.96*sd[i]
-	}
-
-	lines(x, exp(lower), col = "green" ,lty = 2 , lwd = 0.6)
-	lines(x, exp(upper), col = "green" ,lty = 2 , lwd = 0.6)
-	polygon(c(x, rev(x)),c(exp(upper), rev(exp(lower))),col='grey',border = NA, lty=3, density=20)
-
-
+	
 	#bb <- splineDesign(model_cur$knots_a, x = x, ord=order, outer.ok = TRUE)
 	lines(x, points_a, col = "red", lwd = 2)
 
-	fisher_a <- model_cur$cov_a_mc
+	fisher_a <- model_cur$cov_mc[1:n_a,1:n_a]
 	lower <- rep(NA, length(x))
 	upper <- rep(NA, length(x))
 	sd <- rep(NA, length(x))
@@ -102,9 +89,27 @@ plot_AtCtEtp <- function(AtCtEtp_mcmc)
 	lines(x, exp(upper), col = "orange" ,lty = 2 , lwd = 0.6)
 	polygon(c(x, rev(x)),c(exp(upper), rev(exp(lower))),col='grey',border = NA, lty=3, density=20)
 
+	
+	lines(x, points_c, col = "blue", lwd = 2)
+	fisher_c <- model_cur$cov_mc[(n_a+1):(n_a+n_c),(n_a+1):(n_a+n_c)]
+	lower <- rep(NA, length(x))
+	upper <- rep(NA, length(x))
+	sd <- rep(NA, length(x))
+
+	for(i in 1:length(x))
+	{
+		sd[i] <- sqrt((t(bb_c[i,])%*%fisher_c%*%bb_c[i,]))
+		lower[i] <- sum(bb_c[i,]*model_cur$beta_c_mc) - 1.96*sd[i]
+		upper[i] <- sum(bb_c[i,]*model_cur$beta_c_mc) + 1.96*sd[i]
+	}
+
+	lines(x, exp(lower), col = "green" ,lty = 2 , lwd = 0.6)
+	lines(x, exp(upper), col = "green" ,lty = 2 , lwd = 0.6)
+	polygon(c(x, rev(x)),c(exp(upper), rev(exp(lower))),col='grey',border = NA, lty=3, density=20)
+
 	lines(x, points_e, col = "pink", lwd = 2)
 
-	fisher_e <- model_cur$cov_e_mc
+	fisher_e <- model_cur$cov_mc[(n_a+n_c+1):(n_a+n_c+n_e),(n_a+n_c+1):(n_a+n_c+n_e)]
 	lower <- rep(NA, length(x))
 	upper <- rep(NA, length(x))
 	sd <- rep(NA, length(x))
